@@ -1,7 +1,6 @@
 import serial
 import os
-from datetime import datetime
-from kb_controller.helpers import kb_config, kb_central, microbit, event_poller
+from kb_controller.helpers import kb_config, kb_central, microbit, event_poller, helper
 
 current_track_id = 0
 department_id = 0
@@ -10,7 +9,7 @@ tracks_per_department = {}
 def start():
     clear_console()
     print()
-    print(f'  CONTROLLER STARTER OP {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+    print(f'  CONTROLLER STARTER OP {helper.getDateString()}')
     print('================================================')
     print()
 
@@ -39,7 +38,7 @@ def start():
             text = str(byteText, 'utf-8').strip()
 
             if not text == '':
-                print('m:b <<< ' + text)
+                helper.printLog('m:b <<< ' + text)
 
                 if (text == 'quit'):
                     microbit.send_message('OK:QUIT')
@@ -125,7 +124,7 @@ def start():
     microbit.close_connection()
 
     print()
-    print(f'FARVEL! Controlleren lukker ned nu! {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+    print(f'FARVEL! Controlleren lukker ned nu! {helper.getDateString()}')
     print()
     
 def pop_event(events):
