@@ -4,6 +4,7 @@ from datetime import datetime
 from . import microbit
 from . import kb_config
 from . import kb_central
+from . import helper
 
 thread = None
 
@@ -12,7 +13,7 @@ def kb_central_poller(current_track_id):
     while True:
         print()
         print('- - - - - - - - - - - - - - - - - - - - -')
-        print(f'{datetime.now().strftime("%Y-%m-%d %H:%M:%S")} POLLER CENTRAL...')
+        print(f'{helper.getDateString()} POLLER CENTRAL...')
 
         count = kb_central.get_number_of_events_for_track(current_track_id)
         microbit.send_message(f'EVENT-TRACKS:{current_track_id}:{count}')
