@@ -2,7 +2,7 @@ import jwt
 from requests.auth import HTTPBasicAuth
 import requests
 from datetime import datetime
-from . import kb_config
+from . import kb_config, helper
 
 jwt_token = None
 
@@ -72,7 +72,7 @@ def get_auth_jwt_token():
 def request_token_from_kb_cetral():
     basic = HTTPBasicAuth(kb_config.api_user, kb_config.pwd)
     url = f'{kb_config.kbc_host}auth/token'
-    print(f'KB-CENTRAL >>> {url}')
+    helper.printLog(f'KB-CENTRAL >>> {url}')
     try:
         response = requests.get(url, auth=basic)
     except requests.exceptions.ConnectionError as e:
@@ -93,13 +93,13 @@ def validate_response(response):
     if not response.status_code == 200:
         raise Exception(f'Response not OK! URL: {response.url} (status = {response.status_code})')
     
-    print(f'KB-CENTRAL <<< Response status OK!')
+    helper.printLog(f'KB-CENTRAL <<< Response status OK!')
     print()
 
     
 def get_request_to_host(endpoint):
     url = f'{kb_config.kbc_host}{endpoint}'
-    print(f'KB-CENTRAL >>> {url}  [GET]')
+    helper.printLog(f'KB-CENTRAL >>> {url}  [GET]')
     try:
         response = requests.get(url, headers=get_jwt_bearer_auth_header())
     except requests.exceptions.ConnectionError as e:
@@ -110,7 +110,7 @@ def get_request_to_host(endpoint):
     
 def post_request_to_host(endpoint):
     url = f'{kb_config.kbc_host}{endpoint}'
-    print(f'KB-CENTRAL >>> {url}  [POST]')
+    helper.printLog(f'KB-CENTRAL >>> {url}  [POST]')
     try:
         response = requests.post(url, headers=get_jwt_bearer_auth_header())
     except requests.exceptions.ConnectionError as e:
@@ -121,7 +121,7 @@ def post_request_to_host(endpoint):
 
 def delete_request_to_host(endpoint):
     url = f'{kb_config.kbc_host}{endpoint}'
-    print(f'KB-CENTRAL >>> {url}  [DELETE]')
+    helper.printLog(f'KB-CENTRAL >>> {url}  [DELETE]')
     try:
         response = requests.delete(url, headers=get_jwt_bearer_auth_header())
     except requests.exceptions.ConnectionError as e:
