@@ -1,7 +1,7 @@
 from time import sleep
 import serial
 from serial.tools.list_ports import comports
-from . import kb_config
+from . import kb_config, helper
 
 ser = None
 
@@ -10,7 +10,7 @@ def send_message(msg):
     if ser is None:
         initialize_connection()
 
-    print('m:b >>> ' + msg)
+    helper.printLog('m:b >>> ' + msg)
     ser.write(bytes(msg, 'utf-8'))
     # ensure that the controller do not pick up the message itself 
     sleep(0.2)
